@@ -695,7 +695,7 @@ on_help_button_clicked (GtkWidget *widget, gpointer data)
 	GError *error = NULL;
 
         gnome_help_display_desktop (NULL, "user-guide", 
-				    "wgoseditmainmenu.xml", "goseditmainmenu-53", 
+				    "user-guide.xml", "goseditmainmenu-53", 
 				    &error);
 	
 	if (error) {
@@ -1024,6 +1024,50 @@ drag_begin (GtkWidget *widget, GdkDragContext *context)
 	start_temporary ();
 }
 
+static void
+update_window_icon (GtkWindow    *window,
+		    GtkIconTheme *theme,
+		    const char   *icon_name)
+{
+	GtkIconInfo *icon;
+	const char  *filename;
+
+	icon = gtk_icon_theme_lookup_icon (theme, icon_name, 48, 0);
+	if (!icon)
+		return;
+
+	filename = gtk_icon_info_get_filename (icon);
+	g_assert (filename != NULL);
+
+	gtk_window_set_icon_from_file (window, filename, NULL);
+
+	gtk_icon_info_free (icon);
+}
+
+static void
+icon_theme_changed (GtkWindow    *window,
+		    GtkIconTheme *theme)
+{
+	update_window_icon (window, theme, "gnome-screenshot");
+}
+
+static void
+set_window_icon (GtkWindow *window)
+{
+	GdkScreen    *screen;
+	GtkIconTheme *theme;
+
+	screen = gtk_window_get_screen (window);
+	theme  = gtk_icon_theme_get_for_screen (screen);
+
+	g_signal_connect_object (theme, "changed",
+				 G_CALLBACK (icon_theme_changed),
+				 window,
+				 G_CONNECT_SWAPPED);
+
+	update_window_icon (window, theme, "gnome-screenshot");
+}
+
 /* To make sure there is only one screenshot taken at a time,
  * (Imagine key repeat for the print screen key) we hold a selection
  * until we are done taking the screenshot
@@ -1088,18 +1132,21 @@ main (int argc, char *argv[])
 	GConfClient *gconf_client;
 	GnomeClient *client;
 	struct stat s;
-	gchar *file, *window_icon;
+	gchar *file;
 	gboolean window = FALSE;
 	gint width, height; 
 	guint delay = 0;
 	gchar *utf8_name;
 	
 	struct poptOption opts[] = {
-		{"window", '\0', POPT_ARG_NONE, &window, 0, N_("Grab a window instead of the entire screen"), NULL},
-		{"delay", '\0', POPT_ARG_INT, &delay, 0, N_("Take screenshot after specified delay [in seconds]"), NULL},
+		{"window", '\0', POPT_ARG_NONE, NULL, 0, N_("Grab a window instead of the entire screen"), NULL},
+		{"delay", '\0', POPT_ARG_INT, NULL, 0, N_("Take screenshot after specified delay [in seconds]"), NULL},
 		{NULL, '\0', 0, NULL, 0, NULL, NULL}
 	};
 
+	opts[0].arg = &window;
+	opts[1].arg = &delay;
+
 	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -1133,13 +1180,8 @@ main (int argc, char *argv[])
 		take_screen_shot ();
 	}
 
-	if (g_file_test ("gnome-panel-screenshot.glade", G_FILE_TEST_EXISTS)) {
-		xml = glade_xml_new ("gnome-panel-screenshot.glade", NULL, NULL);
-	}
-	if (xml == NULL) {
-		xml = glade_xml_new (GLADEDIR "/gnome-panel-screenshot.glade",
-				     NULL, NULL);
-	}
+	xml = glade_xml_new (GLADEDIR "/gnome-panel-screenshot.glade",
+			     NULL, NULL);
 	if (xml == NULL) {
 		GtkWidget *dialog;
 		release_lock ();
@@ -1182,14 +1224,8 @@ main (int argc, char *argv[])
 	preview = glade_xml_get_widget (xml, "preview");
 	save_entry = glade_xml_get_widget (xml, "save_entry");
 
-	window_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
-						 "gnome-screenshot.png", TRUE, NULL);
-	if (window_icon) {
-		gnome_window_icon_set_from_file (GTK_WINDOW (toplevel), window_icon);
-		g_free (window_icon);
-	}
+	set_window_icon (GTK_WINDOW (toplevel));
 
-	
 	gtk_window_set_default_size (GTK_WINDOW (toplevel), width * 2, -1);
 	gtk_widget_set_size_request (preview, width, height);
 	gtk_aspect_frame_set (GTK_ASPECT_FRAME (frame), 0.0, 0.5,
